@@ -449,7 +449,7 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 			sldrVOLUME->textsize(14);
 			sldrVOLUME->callback((Fl_Callback*)cb_sldrVOLUME);
 			sldrVOLUME->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
-			sldrVOLUME->when(FL_WHEN_CHANGED | FL_LEAVE);
+			sldrVOLUME->when(FL_WHEN_CHANGED | FL_MOUSEWHEEL | FL_LEAVE);
 			Fl_Group::current()->resizable(sldrVOLUME);
 			sldrVOLUME->reverse(true);
 
