@@ -91,6 +91,7 @@ Fl_Value_Input *poll_split = (Fl_Value_Input *)0;
 Fl_Value_Input *poll_noise = (Fl_Value_Input *)0;
 Fl_Value_Input *poll_nr = (Fl_Value_Input *)0;
 Fl_Value_Input *poll_compression = (Fl_Value_Input *)0;
+Fl_Value_Input *poll_tuner = (Fl_Value_Input *)0;
 Fl_Button *btnClearAddControls = (Fl_Button *)0;
 
 Fl_Value_Input *poll_meters = (Fl_Value_Input *)0;
@@ -130,9 +131,18 @@ Fl_Group *tabCOMMANDS = (Fl_Group *)0;
 Fl_Tabs  *tabCmds = (Fl_Tabs *)0;
 Fl_Group *tabCmds1 = (Fl_Group *)0;
 Fl_Group *tabCmds2 = (Fl_Group *)0;
+Fl_Group *tabCmds3 = (Fl_Group *)0;
+Fl_Group *tabCmds4 = (Fl_Group *)0;
+
+Fl_Box *bx1a = (Fl_Box *)0;
+Fl_Box *bx1b = (Fl_Box *)0;
+Fl_Box *bx2a = (Fl_Box *)0;
+Fl_Box *bx2b = (Fl_Box *)0;
+Fl_Box *bx3a = (Fl_Box *)0;
+Fl_Box *bx3b = (Fl_Box *)0;
+Fl_Box *bx4a = (Fl_Box *)0;
+Fl_Box *bx4b = (Fl_Box *)0;
 
-Fl_Box *bx1 = (Fl_Box *)0;
-Fl_Box *bx2 = (Fl_Box *)0;
 Fl_Input2 * cmdlbl1 = (Fl_Input2 *)0;
 Fl_Input2 * cmdlbl2 = (Fl_Input2 *)0;
 Fl_Input2 * cmdlbl3 = (Fl_Input2 *)0;
@@ -167,6 +177,23 @@ Fl_Input2 * cmdtext14 = (Fl_Input2 *)0;
 Fl_Input2 * cmdtext15 = (Fl_Input2 *)0;
 Fl_Input2 * cmdtext16 = (Fl_Input2 *)0;
 
+Fl_Input2 * shftcmdtext1 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext2 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext3 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext4 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext5 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext6 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext7 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext8 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext9 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext10 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext11 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext12 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext13 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext14 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext15 = (Fl_Input2 *)0;
+Fl_Input2 * shftcmdtext16 = (Fl_Input2 *)0;
+
 Fl_Output * cmdResponse = (Fl_Output *)0;
 
 Fl_Group *tabRESTORE = (Fl_Group *)0;
@@ -489,13 +516,17 @@ static void cb_poll_noise(Fl_Value_Input* o, void*) {
 }
 
 static void cb_poll_nr(Fl_Value_Input* o, void*) {
-	progStatus.poll_noise = o->value();
+	progStatus.poll_nr = o->value();
 }
 
 static void cb_poll_compression(Fl_Value_Input* o, void *) {
 	progStatus.poll_compression = o->value();
 }
 
+static void cb_poll_tuner(Fl_Value_Input* o, void *) {
+	progStatus.poll_tuner = o->value();
+}
+
 static void cb_poll_meters(Fl_Value_Input* o, void*) {
 	progStatus.poll_meters = o->value();
 }
@@ -544,6 +575,7 @@ static void cb_btnSetAdd(Fl_Button*, void*) {
 	poll_noise->value(progStatus.poll_all);
 	poll_nr->value(progStatus.poll_all);
 	poll_compression->value(progStatus.poll_all);
+	poll_tuner->value(progStatus.poll_all);
 
 	progStatus.poll_volume = progStatus.poll_all;
 	progStatus.poll_micgain = progStatus.poll_all;
@@ -558,6 +590,7 @@ static void cb_btnSetAdd(Fl_Button*, void*) {
 	progStatus.poll_noise = progStatus.poll_all;
 	progStatus.poll_nr = progStatus.poll_all;
 	progStatus.poll_compression = progStatus.poll_all;
+	progStatus.poll_tuner = progStatus.poll_all;
 }
 
 static void cb_btn_send_command(Fl_Button *o, void*) {
@@ -596,7 +629,7 @@ static void cb_btn_icom_post(Fl_Button *o, void*) {
 }
 
 static void cb_cmdlbl(Fl_Input2 *o, void *d) {
-	long val = reinterpret_cast<long>(d) - 1;
+	long val = reinterpret_cast<long>(d);
 	struct BPAIR { std::string *plbl; Fl_Button *b; } bpairs[] =
 	{ { &progStatus.label1, btnUser1 },
 	  { &progStatus.label2, btnUser2 },
@@ -624,7 +657,7 @@ static void cb_cmdlbl(Fl_Input2 *o, void *d) {
 }
 
 static void cb_cmdtext(Fl_Input2 *o, void *d) {
-	long val = reinterpret_cast<long>(d) - 1;
+	long val = reinterpret_cast<long>(d);
 	std::string *cmd[] =
 	{ &progStatus.command1, &progStatus.command2,
 	  &progStatus.command3, &progStatus.command4,
@@ -640,6 +673,23 @@ static void cb_cmdtext(Fl_Input2 *o, void *d) {
 	*cmd[val] = o->value();
 }
 
+static void cb_shftcmdtext(Fl_Input2 *o, void *d) {
+	long val = reinterpret_cast<long>(d);
+	std::string *cmd[] =
+	{ &progStatus.shftcmd1, &progStatus.shftcmd2,
+	  &progStatus.shftcmd3, &progStatus.shftcmd4,
+	  &progStatus.shftcmd5, &progStatus.shftcmd6,
+	  &progStatus.shftcmd7, &progStatus.shftcmd8,
+	  &progStatus.shftcmd9, &progStatus.shftcmd10,
+	  &progStatus.shftcmd11, &progStatus.shftcmd12,
+	  &progStatus.shftcmd13, &progStatus.shftcmd14,
+	  &progStatus.shftcmd15, &progStatus.shftcmd16 };
+	if (val < 0) val = 0;
+	if (val > 15) val = 15;
+
+	*cmd[val] = o->value();
+}
+
 static void cb_btnOkXcvrDialog(Fl_Return_Button*, void*) {
 	string p1 = selectCommPort->value();
 	string p2 = selectAuxPort->value();
@@ -1386,6 +1436,14 @@ Fl_Group *createPOLLING(int X, int Y, int W, int H, const char *label)
 		poll_auto_notch->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_auto_notch->value(progStatus.poll_auto_notch);
 
+		poll_tuner = new Fl_Value_Input(X + 280, Y + 140, 30, 20, _("Tuner"));
+		poll_tuner->tooltip(_("Auto Tuner"));
+		poll_tuner->maximum(10);
+		poll_tuner->step(1);
+		poll_tuner->callback((Fl_Callback*)cb_poll_tuner);
+		poll_tuner->align(Fl_Align(FL_ALIGN_RIGHT));
+		poll_tuner->value(progStatus.poll_tuner);
+
 		poll_pre_att = new Fl_Value_Input(X + 10, Y + 165, 30, 20, _("Pre/Att"));
 		poll_pre_att->tooltip(_("Preamp / Attenuator"));
 		poll_pre_att->maximum(10);
@@ -1424,7 +1482,7 @@ Fl_Group *createPOLLING(int X, int Y, int W, int H, const char *label)
 		poll_nr->step(1);
 		poll_nr->callback((Fl_Callback*)cb_poll_nr);
 		poll_nr->align(Fl_Align(FL_ALIGN_RIGHT));
-		poll_nr->value(progStatus.poll_noise);
+		poll_nr->value(progStatus.poll_nr);
 
 		poll_compression = new Fl_Value_Input(X + 190, Y + 190, 30, 20, _("Comp'"));
 		poll_compression->tooltip(_("Compression"));
@@ -1495,7 +1553,6 @@ _("Enter text as ASCII string\nOr sequence of hex values, x80 etc separated by s
 
 Fl_Group *createCOMMANDS(int X, int Y, int W, int H, const char *label)
 {
-std::cout << X << ", " << Y << ", " << W << " x " << H << std::endl;
 	Fl_Group *tabCOMMANDS = new Fl_Group(X, Y, W, H, label);
 
 	Fl_Tabs *tabCmds = new Fl_Tabs(X, Y, W, H - 25);
@@ -1507,12 +1564,22 @@ std::cout << X << ", " << Y << ", " << W << " x " << H << std::endl;
 		&progStatus.label13, &progStatus.label14, &progStatus.label15, &progStatus.label16 };
 
 	Fl_Input2 *cmdbtns[] = {
-		cmdlbl1, cmdlbl2,  cmdlbl3,  cmdlbl4,  cmdlbl5,  cmdlbl6,  cmdlbl7,  cmdlbl8,
-		cmdlbl9, cmdlbl10, cmdlbl11, cmdlbl12, cmdlbl13, cmdlbl14, cmdlbl15, cmdlbl16 };
+		cmdlbl1, cmdlbl2,  cmdlbl3,  cmdlbl4,
+		cmdlbl5, cmdlbl6,  cmdlbl7,  cmdlbl8,
+		cmdlbl9, cmdlbl10, cmdlbl11, cmdlbl12,
+		cmdlbl13, cmdlbl14, cmdlbl15, cmdlbl16 };
  
 	Fl_Input2 *cmdtexts[] = {
-		cmdtext1, cmdtext2,  cmdtext3,  cmdtext4,  cmdtext5,  cmdtext6,  cmdtext7,  cmdtext8,
-		cmdtext9, cmdtext10, cmdtext11, cmdtext12, cmdtext13, cmdtext14, cmdtext15, cmdtext16 };
+		cmdtext1, cmdtext2,  cmdtext3,  cmdtext4,
+		cmdtext5,  cmdtext6,  cmdtext7,  cmdtext8,
+		cmdtext9, cmdtext10, cmdtext11, cmdtext12,
+		cmdtext13, cmdtext14, cmdtext15, cmdtext16 };
+ 
+	Fl_Input2 *shftcmdtexts[] = {
+		shftcmdtext1, shftcmdtext2,  shftcmdtext3,  shftcmdtext4,
+		shftcmdtext5, shftcmdtext6,  shftcmdtext7,  shftcmdtext8,
+		shftcmdtext9, shftcmdtext10, shftcmdtext11, shftcmdtext12,
+		shftcmdtext13, shftcmdtext14, shftcmdtext15, shftcmdtext16 };
  
 	std::string *cmd[] = { 
 		&progStatus.command1, &progStatus.command2, &progStatus.command3, &progStatus.command4,
@@ -1520,63 +1587,135 @@ std::cout << X << ", " << Y << ", " << W << " x " << H << std::endl;
 		&progStatus.command9, &progStatus.command10, &progStatus.command11, &progStatus.command12,
 		&progStatus.command13, &progStatus.command14, &progStatus.command15, &progStatus.command16 };
 
-	tabCmds1 = new Fl_Group(X, Y + 20, W, H - 50, _("1-8"));
+	std::string *shftcmd[] = { 
+		&progStatus.shftcmd1, &progStatus.shftcmd2, &progStatus.shftcmd3, &progStatus.shftcmd4,
+		&progStatus.shftcmd5, &progStatus.shftcmd6, &progStatus.shftcmd7, &progStatus.shftcmd8,
+		&progStatus.shftcmd9, &progStatus.shftcmd10, &progStatus.shftcmd11, &progStatus.shftcmd12,
+		&progStatus.shftcmd13, &progStatus.shftcmd14, &progStatus.shftcmd15, &progStatus.shftcmd16 };
 
-		bx1 = new Fl_Box(X + 23, Y + 26, 75, 16, "Label");
-		bx1->box(FL_FLAT_BOX);
-		bx1->align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE);
+	static const char *lbl[16] = {
+		"1", "2", "3", "4", 
+		"5", "6", "7", "8",
+		"9", "10", "11", "12", 
+		"13", "14", "15", "16"};
 
-		bx2 = new Fl_Box(X + 80, Y + 26, W - 80 - 2, 16, "Command");
-		bx2->box(FL_FLAT_BOX);
-		bx2->align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE);
+	tabCmds1 = new Fl_Group(X, Y + 20, W, H - 50, _("1-4"));
 
-		static char *lbl[16] = {
-			"1", "2", "3", "4", "5", "6", "7", "8",
-			"9", "10", "11", "12", "13", "14", "15", "16"};
+		bx1a = new Fl_Box(X + 23, Y + 26, 75, 16, "Label");
+		bx1a->box(FL_FLAT_BOX);
+		bx1a->align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE);
 
-		for (int n = 0; n < 8; n++) {
+		bx1b = new Fl_Box(X + 80, Y + 26, W - 80 - 2, 16, "Command");
+		bx1b->box(FL_FLAT_BOX);
+		bx1b->align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE);
 
-			cmdbtns[n] = new Fl_Input2(X + 27, Y + 46 + (n % 8) * 20, 80, 20, lbl[n]);
+		for (int n = 0; n < 4; n++) {
+			cmdbtns[n] = new Fl_Input2(X + 27, Y + 46 + (n % 4) * 40, 80, 20, lbl[n]);
 			cmdbtns[n]->align(FL_ALIGN_LEFT);
 			cmdbtns[n]->value(cmdlbls[n]->c_str());
 			cmdbtns[n]->callback((Fl_Callback*)cb_cmdlbl, (void *)long(n));
 
-			cmdtexts[n] = new Fl_Input2(X + 110, Y + 46 + (n % 8) * 20, W - 110 - 2, 20, "");
+			cmdtexts[n] = new Fl_Input2(X + 110, Y + 46 + (n % 4) * 40, W - 110 - 2, 20, "");
 			cmdtexts[n]->align(FL_ALIGN_LEFT);
 			cmdtexts[n]->value(cmd[n]->c_str());
 			cmdtexts[n]->callback((Fl_Callback*)cb_cmdtext, (void *)long(n));
 
+			shftcmdtexts[n] = new Fl_Input2(X + 110, Y + 66 + (n % 4) * 40, W - 110 - 2, 20, "SHIFT");
+			shftcmdtexts[n]->align(FL_ALIGN_LEFT);
+			shftcmdtexts[n]->value(shftcmd[n]->c_str());
+			shftcmdtexts[n]->callback((Fl_Callback*)cb_shftcmdtext, (void *)long(n));
 		}
 
 	tabCmds1->end();
 
-	tabCmds2 = new Fl_Group(X, Y + 20, W, H - 50, _("9-16"));
-		tabCmds2->hide();
+	tabCmds2 = new Fl_Group(X, Y + 20, W, H - 50, _("5-8"));
 
-		Fl_Box *bx2a = new Fl_Box(X + 23, Y + 26, 75, 16, "Label");
+		bx2a = new Fl_Box(X + 23, Y + 26, 75, 16, "Label");
 		bx2a->box(FL_FLAT_BOX);
 		bx2a->align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE);
 
-		Fl_Box *bx2b = new Fl_Box(X + 80, Y + 26, W - 80 - 2, 16, "Command");
+		bx2b = new Fl_Box(X + 80, Y + 26, W - 80 - 2, 16, "Command");
 		bx2b->box(FL_FLAT_BOX);
 		bx2b->align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE);
 
-		for (int n = 8; n < 16; n++) {
-
-			cmdbtns[n] = new Fl_Input2(X + 27,  Y + 46 + (n % 8) * 20, 80, 20, lbl[n]);
+		for (int n = 4; n < 8; n++) {
+			cmdbtns[n] = new Fl_Input2(X + 27, Y + 46 + (n % 4) * 40, 80, 20, lbl[n]);
 			cmdbtns[n]->align(FL_ALIGN_LEFT);
 			cmdbtns[n]->value(cmdlbls[n]->c_str());
 			cmdbtns[n]->callback((Fl_Callback*)cb_cmdlbl, (void *)long(n));
 
-			cmdtexts[n] = new Fl_Input2(X + 110,  Y + 46 + (n % 8) * 20, W - 110 - 2, 20, "");
+			cmdtexts[n] = new Fl_Input2(X + 110, Y + 46 + (n % 4) * 40, W - 110 - 2, 20, "");
 			cmdtexts[n]->align(FL_ALIGN_LEFT);
 			cmdtexts[n]->value(cmd[n]->c_str());
 			cmdtexts[n]->callback((Fl_Callback*)cb_cmdtext, (void *)long(n));
 
+			shftcmdtexts[n] = new Fl_Input2(X + 110, Y + 66 + (n % 4) * 40, W - 110 - 2, 20, "SHIFT");
+			shftcmdtexts[n]->align(FL_ALIGN_LEFT);
+			shftcmdtexts[n]->value(shftcmd[n]->c_str());
+			shftcmdtexts[n]->callback((Fl_Callback*)cb_shftcmdtext, (void *)long(n));
 		}
 
 	tabCmds2->end();
 
+	tabCmds3 = new Fl_Group(X, Y + 20, W, H - 50, _("9-12"));
+		tabCmds2->hide();
+
+		bx3a = new Fl_Box(X + 23, Y + 26, 75, 16, "Label");
+		bx3a->box(FL_FLAT_BOX);
+		bx3a->align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE);
+
+		bx3b = new Fl_Box(X + 80, Y + 26, W - 80 - 2, 16, "Command");
+		bx3b->box(FL_FLAT_BOX);
+		bx3b->align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE);
+
+		for (int n = 8; n < 12; n++) {
+			cmdbtns[n] = new Fl_Input2(X + 27, Y + 46 + (n % 4) * 40, 80, 20, lbl[n]);
+			cmdbtns[n]->align(FL_ALIGN_LEFT);
+			cmdbtns[n]->value(cmdlbls[n]->c_str());
+			cmdbtns[n]->callback((Fl_Callback*)cb_cmdlbl, (void *)long(n));
+
+			cmdtexts[n] = new Fl_Input2(X + 110, Y + 46 + (n % 4) * 40, W - 110 - 2, 20, "");
+			cmdtexts[n]->align(FL_ALIGN_LEFT);
+			cmdtexts[n]->value(cmd[n]->c_str());
+			cmdtexts[n]->callback((Fl_Callback*)cb_cmdtext, (void *)long(n));
+
+			shftcmdtexts[n] = new Fl_Input2(X + 110, Y + 66 + (n % 4) * 40, W - 110 - 2, 20, "SHIFT");
+			shftcmdtexts[n]->align(FL_ALIGN_LEFT);
+			shftcmdtexts[n]->value(shftcmd[n]->c_str());
+			shftcmdtexts[n]->callback((Fl_Callback*)cb_shftcmdtext, (void *)long(n));
+		}
+
+	tabCmds3->end();
+
+	tabCmds4 = new Fl_Group(X, Y + 20, W, H - 50, _("13-16"));
+
+		bx4a = new Fl_Box(X + 23, Y + 26, 75, 16, "Label");
+		bx4a->box(FL_FLAT_BOX);
+		bx4a->align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE);
+
+		bx4b = new Fl_Box(X + 80, Y + 26, W - 80 - 2, 16, "Command");
+		bx4b->box(FL_FLAT_BOX);
+		bx4b->align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE);
+
+		for (int n = 12; n < 16; n++) {
+			cmdbtns[n] = new Fl_Input2(X + 27, Y + 46 + (n % 4) * 40, 80, 20, lbl[n]);
+			cmdbtns[n]->align(FL_ALIGN_LEFT);
+			cmdbtns[n]->value(cmdlbls[n]->c_str());
+			cmdbtns[n]->callback((Fl_Callback*)cb_cmdlbl, (void *)long(n));
+
+			cmdtexts[n] = new Fl_Input2(X + 110, Y + 46 + (n % 4) * 40, W - 110 - 2, 20, "");
+			cmdtexts[n]->align(FL_ALIGN_LEFT);
+			cmdtexts[n]->value(cmd[n]->c_str());
+			cmdtexts[n]->callback((Fl_Callback*)cb_cmdtext, (void *)long(n));
+
+			shftcmdtexts[n] = new Fl_Input2(X + 110, Y + 66 + (n % 4) * 40, W - 110 - 2, 20, "SHIFT");
+			shftcmdtexts[n]->align(FL_ALIGN_LEFT);
+			shftcmdtexts[n]->value(shftcmd[n]->c_str());
+			shftcmdtexts[n]->callback((Fl_Callback*)cb_shftcmdtext, (void *)long(n));
+		}
+
+	tabCmds4->end();
+
 	tabCmds->end();
 
 	cmdResponse = new Fl_Output(cmdtexts[0]->x(), Y + H - 20, cmdtexts[0]->w(), 20, "Response:");
