@@ -30,6 +30,8 @@ public:
 	RIG_IC7300();
 	~RIG_IC7300(){}
 
+	bool CW_sense;
+
 	void initialize();
 
 	void selectA();
@@ -184,6 +186,8 @@ public:
 	void set_band_selection(int v);
 	void get_band_selection(int v);
 
+	void set_xcvr_auto_on();
+	void set_xcvr_auto_off();
 };
 
 #endif
