@@ -91,6 +91,7 @@ struct status {
 	int		poll_meters;
 	int		poll_ops;
 	int		poll_compression;
+	int		poll_tuner;
 	int		poll_all;
 
 	int		iBW_A;
@@ -255,37 +256,53 @@ struct status {
 // User command buttons
    string	label1;
    string	command1;
+   string	shftcmd1;
    string	label2;
    string	command2;
+   string	shftcmd2;
    string	label3;
    string	command3;
+   string	shftcmd3;
    string	label4;
    string	command4;
+   string	shftcmd4;
    string	label5;
    string	command5;
+   string	shftcmd5;
    string	label6;
    string	command6;
+   string	shftcmd6;
    string	label7;
    string	command7;
+   string	shftcmd7;
    string	label8;
    string	command8;
+   string	shftcmd8;
 
    string	label9;
    string	command9;
+   string	shftcmd9;
    string	label10;
    string	command10;
+   string	shftcmd10;
    string	label11;
    string	command11;
+   string	shftcmd11;
    string	label12;
    string	command12;
+   string	shftcmd12;
    string	label13;
    string	command13;
+   string	shftcmd13;
    string	label14;
    string	command14;
+   string	shftcmd14;
    string	label15;
    string	command15;
+   string	shftcmd15;
    string	label16;
    string	command16;
+   string	shftcmd16;
 // =========================
 	int		bg_red;
 	int		bg_green;
