@@ -22,7 +22,6 @@
 
 #include <iostream>
 #include <sstream>
-#define IC7100_DEBUG
 
 //=============================================================================
 // IC-7100
@@ -32,7 +31,20 @@
 
 const char IC7100name_[] = "IC-7100";
 
-static int nummodes = 10;
+static int nummodes = 14;
+
+// these are only defined in this file
+// undef'd at end of file
+#define NUM_FILTERS 3
+#define NUM_MODES  14
+
+static int mode_filterA[NUM_MODES] = {1,1,1,1,1,1,1,1,1,1,1,1,1,1};
+static int mode_filterB[NUM_MODES] = {1,1,1,1,1,1,1,1,1,1,1,1,1,1};
+
+static int mode_bwA[NUM_MODES] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
+static int mode_bwB[NUM_MODES] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
+
+static const char *szfilter[NUM_FILTERS] = {"1", "2", "3"};
 
 const char *IC7100modes_[] = {
 "LSB", "USB", "AM", "CW", "RTTY",
@@ -44,7 +56,9 @@ enum {
 	FM7100, WFM7100, CWR7100, RTTYR7100, DV7100,
 	LSBD7100, USBD7100, AMD7100, FMD7100 };
 
-const char IC7100_mode_type[] = {
+static const char mdval[] = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 17, 0, 1, 2, 5};
+
+static char IC7100_mode_type[] = {
 	'L', 'U', 'U', 'L', 'L',
 	'U', 'U', 'U', 'U', 'U', 
 	'L', 'U', 'U', 'U' };
@@ -84,7 +98,7 @@ const char *IC7100_am_bws[] = {
 "200",   "400",  "600",  "800", "1000", "1200", "1400", "1600", "1800", "2000",
 "2200", "2400", "2600", "2800", "3000", "3200", "3400", "3600", "3800", "4000",
 "4200", "4400", "4600", "4800", "5000", "5200", "5400", "5600", "5800", "6000",
-"6200", "6400", "6600", "6800", "7000", "7200", "7400", "7100", "7800", "8000",
+"6200", "6400", "6600", "6800", "7000", "7100", "7400", "7100", "7800", "8000",
 "8200", "8400", "8600", "8800", "9000", "9200", "9400", "9600", "9800", "10000", 
 NULL };
 static int IC7100_bw_vals_AM[] = {
@@ -153,6 +167,7 @@ void RIG_IC7100::initialize()
 
 	choice_rTONE->activate();
 	choice_tTONE->activate();
+
 }
 
 RIG_IC7100::RIG_IC7100() {
@@ -201,6 +216,9 @@ RIG_IC7100::RIG_IC7100() {
 	has_noise_reduction = true;
 	has_noise_reduction_control = true;
 
+	has_auto_notch = true;
+	has_notch_control = true;
+
 	has_attenuator_control = true;
 	has_preamp_control = true;
 
@@ -223,14 +241,17 @@ RIG_IC7100::RIG_IC7100() {
 
 	has_compON = true;
 	has_compression = true;
+	has_vfo_adj = true;
 
 	has_nb_level = true;
 
 	restore_mbw = true;
 
+	has_xcvr_auto_on_off = true;
+
 	precision = 1;
 	ndigits = 9;
-	filA = filB = 1;
+	A.filter = B.filter = 1;
 
 	def_freq = A.freq = 14070000;
 	def_mode = A.imode = 1;
@@ -240,13 +261,54 @@ RIG_IC7100::RIG_IC7100() {
 	B.imode = 1;
 	B.iBW = 34;
 
-
+	CW_sense = 0;
 };
 
 //======================================================================
 // IC7100 unique commands
 //======================================================================
 
+void RIG_IC7100::set_xcvr_auto_on()
+{
+	cmd.clear();
+	int nr = progStatus.comm_baudrate == 6 ? 25 :
+			 progStatus.comm_baudrate == 5 ? 13 :
+			 progStatus.comm_baudrate == 4 ? 7 :
+			 progStatus.comm_baudrate == 3 ? 3 : 2;
+	cmd.append( nr, '\xFE');
+	cmd.append(pre_to);
+	cmd += '\x18'; cmd += '\x01';
+	cmd.append(post);
+	waitFB("Power ON", 2000);
+
+	cmd = pre_to;
+	cmd += '\x19'; cmd += '\x00';
+	cmd.append(post);
+	waitFOR(8, "get ID", 10000);
+}
+
+void RIG_IC7100::set_xcvr_auto_off()
+{
+	cmd.clear();
+	cmd.append(pre_to);
+	cmd += '\x18'; cmd += '\x00';
+	cmd.append(post);
+	waitFB("Power OFF", 200);
+}
+
+bool RIG_IC7100::check ()
+{
+	bool ok = false;
+	string resp = pre_fm;
+	resp += '\x03';
+	cmd = pre_to;
+	cmd += '\x03';
+	cmd.append( post );
+	ok = waitFOR(11, "check vfo");
+	get_trace(2, "check()", str2hex(replystr.c_str(), replystr.length()));
+	return ok;
+}
+
 static bool IC7100onA = true;
 
 void RIG_IC7100::selectA()
@@ -255,11 +317,7 @@ void RIG_IC7100::selectA()
 	cmd += '\x07';
 	cmd += '\x00';
 	cmd.append(post);
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	 ss << " () " <<  str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
+	set_trace(2, "selectA()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("select A");
 	IC7100onA = true;
 }
@@ -270,27 +328,11 @@ void RIG_IC7100::selectB()
 	cmd += '\x07';
 	cmd += '\x01';
 	cmd.append(post);
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	 ss << " () " <<  str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
+	set_trace(2, "selectB()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("select B");
 	IC7100onA = false;
 }
 
-bool RIG_IC7100::check ()
-{
-	string resp = pre_fm;
-	resp += '\x03';
-	cmd = pre_to;
-	cmd += '\x03';
-	cmd.append( post );
-	bool ok = waitFOR(11, "check vfo");
-	rig_trace(2, "check()", str2hex(replystr.c_str(), replystr.length()));
-	return ok;
-}
-
 long RIG_IC7100::get_vfoA ()
 {
 	if (useB) return A.freq;
@@ -304,6 +346,7 @@ long RIG_IC7100::get_vfoA ()
 		if (p != string::npos)
 			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
 	}
+	get_trace(2, "get_vfoA()", str2hex(replystr.c_str(), replystr.length()));
 	return A.freq;
 }
 
@@ -314,12 +357,7 @@ void RIG_IC7100::set_vfoA (long freq)
 	cmd += '\x05';
 	cmd.append( to_bcd_be( freq, 10 ) );
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	 ss << " (" << freq << ") " << 
-		str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
+	set_trace(2, "set_vfoA()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set vfo A");
 }
 
@@ -336,6 +374,7 @@ long RIG_IC7100::get_vfoB ()
 		if (p != string::npos)
 			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
 	}
+	get_trace(2, "get_vfoB()", str2hex(replystr.c_str(), replystr.length()));
 	return B.freq;
 }
 
@@ -346,12 +385,7 @@ void RIG_IC7100::set_vfoB (long freq)
 	cmd += '\x05';
 	cmd.append( to_bcd_be( freq, 10 ) );
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	 ss << " (" << freq << ") " << 
-		str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
+	set_trace(2, "set_vfoB()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set vfo B");
 }
 
@@ -367,12 +401,7 @@ void RIG_IC7100::set_split(bool val)
 	cmd += 0x0F;
 	cmd += val ? 0x01 : 0x00;
 	cmd.append(post);
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	 ss << " (" << val << ") " << 
-		str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
+	set_trace(2, "set_split()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB(val ? "set split ON" : "set split OFF");
 }
 
@@ -391,6 +420,7 @@ int RIG_IC7100::get_split()
 		if (read_split != 0xFA) // fail byte
 			split = read_split;
 	}
+	get_trace(2, "get_split()", str2hex(replystr.c_str(), replystr.length()));
 	return split;
 }
 
@@ -404,6 +434,7 @@ void RIG_IC7100::set_PTT_control(int val)
 	cmd.append( post );
 	waitFB("set ptt");
 	ptt_ = val;
+	set_trace(2, "set_PTT()", str2hex(cmd.c_str(), cmd.length()));
 }
 
 int RIG_IC7100::get_PTT()
@@ -418,6 +449,7 @@ int RIG_IC7100::get_PTT()
 		if (p != string::npos)
 			ptt_ = replystr[p + 6];
 	}
+	get_trace(2, "get_PTT()", str2hex(replystr.c_str(), replystr.length()));
 	return ptt_;
 }
 
@@ -427,65 +459,51 @@ void RIG_IC7100::set_modeA(int val)
 	cmd = pre_to;
 	cmd += '\x06';
 	cmd += IC7100_mode_nbr[val];
-	cmd += filA;
+	if (val < LSBD7100)
+		cmd += A.filter;
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " (" << val << ") [" << IC7100modes_[val] << "] " <<
-		str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("set mode A");
+	set_trace(4, "set mode A[", IC7100modes_[A.imode], "] ", str2hex(replystr.c_str(), replystr.length()));
 
-	cmd = pre_to;
-	cmd += '\x1A'; cmd += '\x06';
 	if (val >= LSBD7100) {
+		cmd = pre_to;
+		cmd += '\x1A'; cmd += '\x06';
 		cmd += '\x01';
-	} else {
-		cmd += '\x00';
+		cmd += A.filter;
+		cmd.append( post);
+		set_trace(2, "set_data_modeA()", str2hex(replystr.c_str(), replystr.length()));
+		waitFB("set data mode A");
 	}
-	cmd += filA;
-	cmd.append( post);
-#ifdef IC7100_DEBUG
-	stringstream ss2;
-	ss2 << " (" << val << ") [" << IC7100modes_[val] << "] " <<
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss2.str().c_str());
-#endif
-	waitFB("set/clear digital");
 }
 
-static const char *szfilter[] = {"1", "2", "3"};
-
 int RIG_IC7100::get_modeA()
 {
 	int md = 0;
+	size_t p = 0;
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
 	string resp = pre_fm;
 	resp += '\x04';
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << "get_modeA() " << str2hex(replystr.c_str(), replystr.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
+
 	if (waitFOR(8, "get mode A")) {
-		size_t p = replystr.rfind(resp);
+		p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			for (md = 0; md < nummodes; md++)
 				if (replystr[p+5] == IC7100_mode_nbr[md]) 
 					break;
-			filA = replystr[p+6];
+			A.filter = replystr[p+6];
 			if (md == nummodes) {
 				checkresponse();
 				return A.imode;
 			}
 		}
+		get_trace(2, "get_modeA()", str2hex(replystr.c_str(), replystr.length()));
 	} else {
 		checkresponse();
 		return A.imode;
 	}
+
 	if (md == LSB7100 || md == USB7100 || md == AM7100 || md == FM7100) {
 		cmd = pre_to;
 		cmd.append("\x1a\x06");
@@ -493,7 +511,7 @@ int RIG_IC7100::get_modeA()
 		resp = pre_fm;
 		resp.append("\x1a\x06");
 		if (waitFOR(9, "get digital setting")) {
-			size_t p = replystr.rfind(resp);
+			p = replystr.rfind(resp);
 			if (p != string::npos) {
 				if ((replystr[p+6] & 0x01) == 0x01) {
 					if (md == USB7100) md = USBD7100;
@@ -502,10 +520,29 @@ int RIG_IC7100::get_modeA()
 					else if (md == FM7100) md = FMD7100;
 				}
 			}
-			if (replystr[p+7]) filA = replystr[p+7];
+			if (replystr[p+7]) A.filter = replystr[p+7];
 		}
 	}
 	A.imode = md;
+	if (A.filter > 0 && A.filter < 4)
+		mode_filterA[A.imode] = A.filter;
+
+	get_trace(2, "get_data_modeA()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(4, "mode_filterA[", IC7100modes_[md], "] = ", szfilter[A.filter-1]);
+
+	if (A.imode == CW7100 || A.imode == CWR7100) {
+		cmd.assign(pre_to).append("\x1A\x05");
+		cmd += '\x00'; cmd += '\x32';
+		resp.assign(pre_fm).append("\x1A\x05");
+		resp += '\x00'; resp += '\x32';
+		if (waitFOR(10, "get CW sideband")) {
+			p = replystr.rfind(resp);
+			CW_sense = replystr[p + 8];
+			if (CW_sense) IC7100_mode_type[A.imode] = 'U';
+			else IC7100_mode_type[A.imode] = 'L';
+		}
+	}
+
 	return A.imode;
 }
 
@@ -515,60 +552,48 @@ void RIG_IC7100::set_modeB(int val)
 	cmd = pre_to;
 	cmd += '\x06';
 	cmd += IC7100_mode_nbr[val];
-	cmd += filB;
+	if (val < LSBD7100)
+		cmd += B.filter;
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	 ss << " (" << val << ") [" << IC7100modes_[val] << "] " <<
-		str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("set mode B");
+	set_trace(4, "set mode B[", IC7100modes_[B.imode], "] ", str2hex(replystr.c_str(), replystr.length()));
 
-// digital set / clear
-	cmd = pre_to;
-	cmd += '\x1A'; cmd += '\x06';
 	if (val >= LSBD7100) {
+		cmd = pre_to;
+		cmd += '\x1A'; cmd += '\x06';
 		cmd += '\x01';
-	} else {
-		cmd += '\x00';
+		cmd += B.filter;
+		cmd.append( post);
+		set_trace(2, "set_data_modeB()", str2hex(replystr.c_str(), replystr.length()));
+		waitFB("set data mode B");
 	}
-	cmd += filB;
-	cmd.append( post);
-#ifdef IC7100_DEBUG
-	stringstream ss2;
-	ss2 << " (" << val << ") [" << IC7100modes_[val] << "] " <<
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss2.str().c_str());
-#endif
-	waitFB("set/clear digital");
 }
 
 int RIG_IC7100::get_modeB()
 {
 	int md = 0;
+	size_t p = 0;
+
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
 	string resp = pre_fm;
 	resp += '\x04';
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << "get_modeB() " << str2hex(replystr.c_str(), replystr.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
+
 	if (waitFOR(8, "get mode B")) {
-		size_t p = replystr.rfind(resp);
+		p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			for (md = LSB7100; md < LSBD7100; md++)
+			for (md = 0; md < nummodes; md++)
 				if (replystr[p+5] == IC7100_mode_nbr[md]) 
 					break;
-			filB = replystr[p+6];
+			if (md > 6) md -= 2;
+			B.filter = replystr[p+6];
 			if (md == nummodes) {
 				checkresponse();
-				return B.imode;
+				return A.imode;
 			}
 		}
+		get_trace(2, "get_modeB()", str2hex(replystr.c_str(), replystr.length()));
 	} else {
 		checkresponse();
 		return B.imode;
@@ -581,7 +606,7 @@ int RIG_IC7100::get_modeB()
 		resp = pre_fm;
 		resp.append("\x1a\x06");
 		if (waitFOR(9, "get digital setting")) {
-			size_t p = replystr.rfind(resp);
+			p = replystr.rfind(resp);
 			if (p != string::npos) {
 				if ((replystr[p+6] & 0x01) == 0x01) {
 					if (md == USB7100) md = USBD7100;
@@ -589,11 +614,30 @@ int RIG_IC7100::get_modeB()
 					else if (md == AM7100) md = AMD7100;
 					else if (md == FM7100) md = FMD7100;
 				}
-				if (replystr[p+7]) filB = replystr[p+7];
 			}
+			if (replystr[p+7]) B.filter = replystr[p+7];
 		}
 	}
 	B.imode = md;
+	if (B.filter > 0 && B.filter < 4)
+		mode_filterA[B.imode] = B.filter;
+
+	get_trace(2, "get_data_modeB()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(4, "mode_filterB[", IC7100modes_[md], "] = ", szfilter[A.filter-1]);
+
+	if (B.imode == CW7100 || B.imode == CWR7100) {
+		cmd.assign(pre_to).append("\x1A\x05");
+		cmd += '\x00'; cmd += '\x32';
+		resp.assign(pre_fm).append("\x1A\x05");
+		resp += '\x00'; resp += '\x32';
+		if (waitFOR(10, "get CW sideband")) {
+			p = replystr.rfind(resp);
+			CW_sense = replystr[p + 8];
+			if (CW_sense) IC7100_mode_type[B.imode] = 'U';
+			else IC7100_mode_type[B.imode] = 'L';
+		}
+	}
+
 	return B.imode;
 }
 
@@ -608,11 +652,6 @@ int RIG_IC7100::get_bwA()
 	cmd.append(post);
 	string resp = pre_fm;
 	resp.append("\x1a\x03");
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << "get_bwA() " << str2hex(replystr.c_str(), replystr.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	if (waitFOR(8, "get bw A")) {
 		size_t p = replystr.rfind(resp);
 		A.iBW = fm_bcd(replystr.substr(p+6), 2);
@@ -632,15 +671,6 @@ void RIG_IC7100::set_bwA(int val)
 	cmd.append("\x1a\x03");
 	cmd.append(to_bcd(A.iBW, 2));
 	cmd.append(post);
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	const char *bwstr = IC7100_ssb_bws[val];
-	if ((A.imode == AM7100) || (A.imode == AMD7100)) bwstr = IC7100_am_bws[val];
-	if ((A.imode == RTTY7100) || (A.imode == RTTYR7100)) bwstr = IC7100_rtty_bws[val];
-	ss << " (" << val << ") [" << bwstr << "] " <<
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("set bw A");
 }
 
@@ -655,11 +685,6 @@ int RIG_IC7100::get_bwB()
 	cmd.append(post);
 	string resp = pre_fm;
 	resp.append("\x1a\x03");
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << "get_bwB() " << str2hex(replystr.c_str(), replystr.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	if (waitFOR(8, "get bw B")) {
 		size_t p = replystr.rfind(resp);
 		B.iBW = fm_bcd(replystr.substr(p+6), 2);
@@ -679,18 +704,29 @@ void RIG_IC7100::set_bwB(int val)
 	cmd.append("\x1a\x03");
 	cmd.append(to_bcd(B.iBW, 2));
 	cmd.append(post);
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	const char *bwstr = IC7100_ssb_bws[val];
-	if ((A.imode == AM7100) || (A.imode == AMD7100)) bwstr = IC7100_am_bws[val];
-	if ((A.imode == RTTY7100) || (A.imode == RTTYR7100)) bwstr = IC7100_rtty_bws[val];
-	ss << " (" << val << ") [" << bwstr << "] " <<
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("set bw B");
 }
 
+std::string RIG_IC7100::get_BANDWIDTHS()
+{
+	stringstream s;
+	for (int i = 0; i < NUM_MODES; i++)
+		s << mode_bwA[i] << " ";
+	for (int i = 0; i < NUM_MODES; i++)
+		s << mode_bwB[i] << " ";
+	return s.str();
+}
+
+void RIG_IC7100::set_BANDWIDTHS(std::string s)
+{
+	stringstream strm;
+	strm << s;
+	for (int i = 0; i < NUM_MODES; i++)
+		strm >> mode_bwA[i];
+	for (int i = 0; i < NUM_MODES; i++)
+		strm >> mode_bwB[i];
+}
+
 int RIG_IC7100::adjust_bandwidth(int m)
 {
 	switch (m) {
@@ -761,6 +797,7 @@ void RIG_IC7100::set_mic_gain(int val)
 	cmd.append("\x14\x0B");
 	cmd.append(bcd255(val));
 	cmd.append( post );
+	set_trace(2, "set_mic_gain()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set mic gain");
 }
 
@@ -778,6 +815,7 @@ int RIG_IC7100::get_mic_gain()
 		if (p != string::npos)
 			val = num100(replystr.substr(p+6));
 	}
+	get_trace(2, "get_mic_gain()", str2hex(replystr.c_str(), replystr.length()));
 	return val;
 }
 
@@ -800,6 +838,7 @@ void RIG_IC7100::set_attenuator(int val)
 	cmd += '\x11';
 	cmd += atten_level ? '\x12' : '\x00';
 	cmd.append( post );
+	set_trace(2, "set_attenuator()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set att");
 }
 
@@ -811,6 +850,7 @@ int RIG_IC7100::get_attenuator()
 	string resp = pre_fm;
 	resp += '\x11';
 	if (waitFOR(7, "get ATT")) {
+		get_trace(2, "get_ATT()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
 		if (replystr[p+5] == 0x12) {
 			atten_level = 1;
@@ -882,6 +922,7 @@ void RIG_IC7100::set_preamp(int val)
 	waitFB(	(preamp_level == 0) ? "set Preamp OFF" :
 			(preamp_level == 1) ? "set Preamp Level 1" :
 			"set Preamp Level 2");
+	set_trace(2, "set_preamp()", str2hex(cmd.c_str(), cmd.length()));
 }
 
 int RIG_IC7100::get_preamp()
@@ -893,6 +934,7 @@ int RIG_IC7100::get_preamp()
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get Preamp Level")) {
+		get_trace(2, "get_preamp()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
 			preamp_level = replystr[p+6];
@@ -928,12 +970,6 @@ void RIG_IC7100::set_compression(int on, int val)
 		cmd.append(post);
 		waitFB("set Comp OFF");
 	}
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	 ss << " (" << on << ", " << val << ") " << 
-		str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 }
 
 void RIG_IC7100::set_vox_onoff()
@@ -941,21 +977,11 @@ void RIG_IC7100::set_vox_onoff()
 	if (progStatus.vox_onoff) {
 		cmd.assign(pre_to).append("\x16\x46\x01");
 		cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	 ss << " () " << str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 		waitFB("set vox ON");
 	} else {
 		cmd.assign(pre_to).append("\x16\x46");
 		cmd += '\x00';
 		cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " () " << str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 		waitFB("set vox OFF");
 	}
 }
@@ -967,12 +993,6 @@ void RIG_IC7100::set_vox_gain()
 	cmd +='\x63';
 	cmd.append(to_bcd((int)(progStatus.vox_gain * 2.55), 3));
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " [" << progStatus.vox_gain << "] " <<
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("SET vox gain");
 }
 
@@ -983,12 +1003,6 @@ void RIG_IC7100::set_vox_anti()
 	cmd +='\x64';
 	cmd.append(to_bcd((int)(progStatus.vox_anti * 2.55), 3));
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " [" << progStatus.vox_anti << "] " <<
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("SET anti-vox");
 }
 
@@ -999,12 +1013,6 @@ void RIG_IC7100::set_vox_hang()
 	cmd +='\x65';
 	cmd.append(to_bcd((int)(progStatus.vox_hang / 10 ), 2));
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " [" << progStatus.vox_hang << "] " <<
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("SET vox hang");
 }
 
@@ -1015,12 +1023,6 @@ void RIG_IC7100::set_cw_wpm()
 	cmd.assign(pre_to).append("\x14\x0C"); // values 0-255 = 6 to 48 WPM
 	cmd.append(to_bcd(round((progStatus.cw_wpm - 6) * 255 / (48 - 6)), 3));
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " [" << progStatus.cw_wpm << "] " <<
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("SET cw wpm");
 }
 
@@ -1030,12 +1032,6 @@ void RIG_IC7100::set_cw_qsk()
 	cmd.assign(pre_to).append("\x14\x0F");
 	cmd.append(to_bcd(n, 3));
 	cmd.append(post);
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " [" << progStatus.cw_qsk << "] " <<
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("Set cw qsk delay");
 }
 
@@ -1047,12 +1043,6 @@ void RIG_IC7100::set_cw_spot_tone()
 	if (n < 0) n = 0;
 	cmd.append(to_bcd(n, 3));
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " [" << progStatus.cw_spot_tone << "] " <<
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("SET cw spot tone");
 }
 
@@ -1064,12 +1054,7 @@ void RIG_IC7100::set_cw_vol()
 	cmd += '\x32';
 	cmd.append(to_bcd((int)(progStatus.cw_vol * 2.55), 3));
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " [" << progStatus.cw_vol << "] " << 
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
+	set_trace(2, "set_cw_vol()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("SET cw sidetone volume");
 }
 
@@ -1079,12 +1064,7 @@ void RIG_IC7100::set_power_control(double val)
 	cmd.append("\x14\x0A");
 	cmd.append(bcd255(val));
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " [" << val << "] " << 
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
+	set_trace(2, "set_power_control()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set power");
 }
 
@@ -1101,6 +1081,7 @@ int RIG_IC7100::get_power_control()
 		if (p != string::npos)
 			val = num100(replystr.substr(p+6));
 	}
+	get_trace(2, "get_power_control()", str2hex(replystr.c_str(), replystr.length()));
 	return val;
 }
 
@@ -1122,12 +1103,7 @@ void RIG_IC7100::set_rf_gain(int val)
 	cmd.append("\x14\x02");
 	cmd.append(bcd255(val));
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " [" << val << "] " << 
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
+	set_trace(2, "set_rf_gain()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set RF");
 }
 
@@ -1151,6 +1127,7 @@ int RIG_IC7100::get_rf_gain()
 		if (p != string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
+	get_trace(2, "get_rf_gain()", str2hex(replystr.c_str(), replystr.length()));
 	return val;
 }
 
@@ -1166,12 +1143,7 @@ void RIG_IC7100::set_volume_control(int val)
 	cmd.append("\x14\x01");
 	cmd.append(bcd255(val));
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " [" << val << "] " << 
-	str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
+	set_trace(2, "set_volume_control()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set vol");
 }
 
@@ -1189,6 +1161,7 @@ int RIG_IC7100::get_volume_control()
 		if (p != string::npos)
 			val = num100(replystr.substr(p+6));
 	}
+	get_trace(2, "get_volume_control()", str2hex(replystr.c_str(), replystr.length()));
 	return val;
 }
 
@@ -1198,6 +1171,7 @@ void RIG_IC7100::set_squelch(int val)
 	cmd.append("\x14\x03");
 	cmd.append(bcd255(val));
 	cmd.append( post );
+	set_trace(2, "set_squelch()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set Sqlch");
 }
 
@@ -1215,6 +1189,7 @@ int  RIG_IC7100::get_squelch()
 		if (p != string::npos)
 			val = num100(replystr.substr(p+6));
 	}
+	get_trace(2, "get_squelch()", str2hex(replystr.c_str(), replystr.length()));
 	return val;
 }
 
@@ -1222,6 +1197,14 @@ void RIG_IC7100::get_vol_min_max_step(int &min, int &max, int &step)
 {
 	min = 0; max = 100; step = 1;
 }
+
+struct meterpair {int mtr; float val;};
+
+static meterpair smtrtbl[] = {
+{0, 0},
+{120, 50},
+{241, 100} };
+
 int RIG_IC7100::get_smeter()
 {
 	string cstr = "\x15\x02";
@@ -1235,14 +1218,34 @@ int RIG_IC7100::get_smeter()
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
-			mtr = (int)ceil(mtr /2.40);
+			size_t i = 0;
+			for (i = 0; i < sizeof(smtrtbl) / sizeof(meterpair) - 1; i++)
+				if (mtr >= smtrtbl[i].mtr && mtr < smtrtbl[i+1].mtr)
+					break;
+			if (mtr < 0) mtr = 0;
+			if (mtr > 255) mtr = 255;
+			mtr = (int)ceil(smtrtbl[i].val + 
+				(smtrtbl[i+1].val - smtrtbl[i].val)*(mtr - smtrtbl[i].mtr)/(smtrtbl[i+1].mtr - smtrtbl[i].mtr));
 			if (mtr > 100) mtr = 100;
 		}
 	}
+	get_trace(2, "get_smeter()", str2hex(replystr.c_str(), replystr.length()));
 	return mtr;
 }
 
-int RIG_IC7100::get_power_out()
+static meterpair pwrtbl[] = { 
+{0, 0.0},
+{40, 10.0},
+{76, 20.0},
+{92, 25.0},
+{103, 30.0},
+{124, 40.0},
+{143, 50.0},
+{183, 75.0},
+{213, 100.0},
+{255, 140.0} };
+
+int RIG_IC7100::get_power_out(void)
 {
 	string cstr = "\x15\x11";
 	string resp = pre_fm;
@@ -1250,15 +1253,23 @@ int RIG_IC7100::get_power_out()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	int mtr= -1;
-	if (waitFOR(9, "get pout")) {
+	int mtr= 0;
+	if (waitFOR(9, "get power out")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
-			mtr = (int)ceil(mtr /2.15);
+			size_t i = 0;
+			for (i = 0; i < sizeof(pwrtbl) / sizeof(meterpair) - 1; i++)
+				if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
+					break;
+			if (mtr < 0) mtr = 0;
+			if (mtr > 255) mtr = 255;
+			mtr = (int)ceil(pwrtbl[i].val + 
+				(pwrtbl[i+1].val - pwrtbl[i].val)*(mtr - pwrtbl[i].mtr)/(pwrtbl[i+1].mtr - pwrtbl[i].mtr));
 			if (mtr > 100) mtr = 100;
 		}
 	}
+	get_trace(2, "get_power_out()", str2hex(replystr.c_str(), replystr.length()));
 	return mtr;
 }
 
@@ -1279,6 +1290,7 @@ int RIG_IC7100::get_swr()
 			if (mtr > 100) mtr = 100;
 		}
 	}
+	get_trace(2, "get_swr()", str2hex(replystr.c_str(), replystr.length()));
 	return mtr;
 }
 
@@ -1295,41 +1307,62 @@ int RIG_IC7100::get_alc()
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
-			mtr = (int)ceil(mtr /2.55);
+			mtr = (int)ceil(mtr /1.2);
 			if (mtr > 100) mtr = 100;
 		}
 	}
+	get_trace(2, "get_alc()", str2hex(replystr.c_str(), replystr.length()));
 	return mtr;
 }
 
-void RIG_IC7100::set_notch(bool on, int val)
+void RIG_IC7100::set_notch(bool on, int freq)
 {
-	int notch = (int)(val * 256.0 / 3000.0);
+	int hexval;
+	switch (vfo->imode) {
+		default: case USB7100: case USBD7100: case RTTYR7100:
+			hexval = freq - 1500;
+			break;
+		case LSB7100: case LSBD7100: case RTTY7100:
+			hexval = 1500 - freq;
+			break;
+		case CW7100:
+			if (CW_sense)
+				hexval = freq - progStatus.cw_spot_tone;
+			else
+				hexval = progStatus.cw_spot_tone - freq;
+			break;
+		case CWR7100:
+			if (CW_sense)
+				hexval = progStatus.cw_spot_tone - freq;
+			else
+				hexval = freq - progStatus.cw_spot_tone;
+			break;
+	}
+
+	hexval /= 20;
+	hexval += 128;
+	if (hexval < 0) hexval = 0;
+	if (hexval > 255) hexval = 255;
 
 	cmd = pre_to;
 	cmd.append("\x16\x48");
 	cmd += on ? '\x01' : '\x00';
 	cmd.append(post);
 	waitFB("set notch");
+	set_trace(2, "set_notch() ", str2hex(cmd.c_str(), cmd.length()));
 
 	cmd = pre_to;
 	cmd.append("\x14\x0D");
-	cmd.append(to_bcd(notch,3));
+	cmd.append(to_bcd(hexval,3));
 	cmd.append(post);
 	waitFB("set notch val");
-
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	 ss << " (" << on << ", " << val << ")" << str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
-
+	set_trace(2, "set_notch_val() ", str2hex(cmd.c_str(), cmd.length()));
 }
 
 bool RIG_IC7100::get_notch(int &val)
 {
 	bool on = false;
-	val = 0;
+	val = 1500;
 
 	string cstr = "\x16\x48";
 	string resp = pre_fm;
@@ -1338,6 +1371,7 @@ bool RIG_IC7100::get_notch(int &val)
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get notch")) {
+		get_trace(2, "get_notch()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
 			on = replystr[p + 6];
@@ -1348,9 +1382,34 @@ bool RIG_IC7100::get_notch(int &val)
 		resp.append(cstr);
 		cmd.append(post);
 		if (waitFOR(9, "notch val")) {
+			get_trace(2, "get_notch_val() ", str2hex(replystr.c_str(), replystr.length()));
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos)
-				val = (int)ceil(fm_bcd(replystr.substr(p+6),3) * 3000.0 / 255.0);
+			if (p != string::npos) {
+				val = (int)ceil(fm_bcd(replystr.substr(p+6),3));
+				val -= 128;
+				val *= 20;
+				switch (vfo->imode) {
+					default: case USB7100: case USBD7100: case RTTYR7100:
+						val = 1500 + val;
+						break;
+					case LSB: case LSBD7100: case RTTY7100:
+						val = 1500 - val;
+						break;
+					case CW7100:
+						if (CW_sense)
+							val = progStatus.cw_spot_tone + val;
+						else
+							val = progStatus.cw_spot_tone - val;
+						break;
+					case CWR7100:
+						if (CW_sense)
+							val = progStatus.cw_spot_tone - val;
+						else
+							val = progStatus.cw_spot_tone + val;
+						break;
+				}
+			}
+			get_trace(2, "get_notch_val() ", str2hex(replystr.c_str(), replystr.length()));
 		}
 	}
 	return on;
@@ -1358,9 +1417,17 @@ bool RIG_IC7100::get_notch(int &val)
 
 void RIG_IC7100::get_notch_min_max_step(int &min, int &max, int &step)
 {
-	min = 0;
-	max = 3000;
-	step = 20;
+	switch (vfo->imode) {
+		default:
+		case USB7100: case USBD7100: case RTTYR7100:
+		case LSB7100: case LSBD7100: case RTTY7100:
+			min = 0; max = 3000; step = 20; break;
+		case CW7100: case CWR7100:
+			min = progStatus.cw_spot_tone - 500;
+			max = progStatus.cw_spot_tone + 500;
+			step = 20;
+			break;
+	}
 }
 
 void RIG_IC7100::set_auto_notch(int val)
@@ -1370,11 +1437,6 @@ void RIG_IC7100::set_auto_notch(int val)
 	cmd += '\x41';
 	cmd += val ? 0x01 : 0x00;
 	cmd.append( post );
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " (" <<  val << ")" << str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("set AN");
 }
 
@@ -1416,22 +1478,12 @@ void RIG_IC7100::set_if_shift(int val)
 	cmd.append("\x14\x07");
 	cmd.append(to_bcd(shift, 3));
 	cmd.append(post);
-#ifdef IC7100_DEBUG
-	stringstream ss;
-	ss << " inner(" <<  val << ")" << str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss.str().c_str());
-#endif
 	waitFB("set IF inner");
 
 	cmd = pre_to;
 	cmd.append("\x14\x08");
 	cmd.append(to_bcd(shift, 3));
 	cmd.append(post);
-#ifdef IC7100_DEBUG
-	stringstream ss2;
-	ss2 << " outer(" <<  val << ")" << str2hex(cmd.data(), cmd.length());
-	LOG_INFO("%s", ss2.str().c_str());
-#endif
 	waitFB("set IF outer");
 }
 
@@ -1520,6 +1572,7 @@ void RIG_IC7100::set_noise(bool val)
 	cmd.append("\x16\x22");
 	cmd += val ? 1 : 0;
 	cmd.append(post);
+	set_trace(2, "set_noise()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set noise");
 }
 
@@ -1533,6 +1586,7 @@ int RIG_IC7100::get_noise()
 	cmd.append(post);
 	if (waitFOR(8, "get noise")) {
 		size_t p = replystr.rfind(resp);
+	get_trace(2, "get_noise()", str2hex(replystr.c_str(), replystr.length()));
 	if (p != string::npos)
 		return (replystr[p+6] ? 1 : 0);
 	}
@@ -1546,6 +1600,7 @@ void RIG_IC7100::set_nb_level(int val)
 	cmd.append("\x14\x12");
 	cmd.append(bcd255(val));
 	cmd.append( post );
+	set_trace(2, "set_nb_level()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set NB level");
 }
 
@@ -1563,6 +1618,7 @@ int  RIG_IC7100::get_nb_level()
 		if (p != string::npos)
 			val = num100(replystr.substr(p+6));
 	}
+	get_trace(2, "get_nb_level()", str2hex(replystr.c_str(), replystr.length()));
 	return val;
 }
 
@@ -1572,6 +1628,7 @@ void RIG_IC7100::set_noise_reduction(int val)
 	cmd.append("\x16\x40");
 	cmd += val ? 1 : 0;
 	cmd.append(post);
+	set_trace(2, "set_noise_reduction()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set NR");
 }
 
@@ -1585,6 +1642,7 @@ int RIG_IC7100::get_noise_reduction()
 	cmd.append(post);
 	if (waitFOR(8, "get NR")) {
 		size_t p = replystr.rfind(resp);
+	get_trace(2, "get_noise_reduction()", str2hex(replystr.c_str(), replystr.length()));
 	if (p != string::npos)
 		return (replystr[p+6] ? 1 : 0);
 	}
@@ -1599,6 +1657,7 @@ void RIG_IC7100::set_noise_reduction_val(int val)
 	val += 8;
 	cmd.append(to_bcd(val, 3));
 	cmd.append(post);
+	set_trace(2, "set_noise_reduction_val()", str2hex(cmd.c_str(), cmd.length()));
 	waitFB("set NRval");
 }
 
@@ -1619,39 +1678,8 @@ int RIG_IC7100::get_noise_reduction_val()
 			val /= 16;
 		}
 	}
-	progStatus.noise_reduction_val = val;
-	return progStatus.noise_reduction_val;
-}
-
-const char *RIG_IC7100::FILT(int &val)
-{
-	if (useB) {
-		if (filB < 0) filB = 0;
-		if (filB > 3) filB = 3;
-		val = filB;
-		return(szfilter[filB - 1]);
-	}
-	else {
-		if (filA < 0) filA = 0;
-		if (filA > 3) filA = 3;
-		val = filA;
-		return (szfilter[filA - 1]);
-	}
-}
-
-const char *RIG_IC7100::nextFILT()
-{
-	if (useB) {
-		filB++;
-		if (filB > 3) filB = 1;
-		set_modeB(B.imode);
-		return(szfilter[filB - 1]);
-	} else {
-		filA++;
-		if (filA > 3) filA = 1;
-		set_modeA(A.imode);
-		return(szfilter[filA - 1]);
-	}
+	get_trace(2, "get_nr_val()", str2hex(replystr.c_str(), replystr.length()));
+	return val;
 }
 
 // Read/Write band stack registers
@@ -1715,7 +1743,7 @@ void RIG_IC7100::get_band_selection(int v)
 void RIG_IC7100::set_band_selection(int v)
 {
 	long freq = (useB ? B.freq : A.freq);
-	int fil = (useB ? filB : filA);
+	int fil = (useB ? B.filter : A.filter);
 	int mode = (useB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
@@ -1744,3 +1772,140 @@ void RIG_IC7100::set_band_selection(int v)
 	waitFOR(23, "get band stack");
 }
 
+void RIG_IC7100::setVfoAdj(double v)
+{
+	vfo_ = v;
+	cmd.assign(pre_to);
+	cmd.append("\x1A\x05");
+	cmd += '\x00';
+	cmd += '\x47';
+	cmd.append(bcd255(int(v)));
+	cmd.append(post);
+	waitFB("SET vfo adjust");
+	set_trace(2, "set_vfo_adj()", str2hex(cmd.c_str(), cmd.length()));
+}
+
+double RIG_IC7100::getVfoAdj()
+{
+	cmd.assign(pre_to);
+	cmd.append("\x1A\x05");
+	cmd += '\x00';
+	cmd += '\x47';
+	cmd.append(post);
+
+	if (waitFOR(11, "get vfo adj")) {
+		size_t p = replystr.find(pre_fm);
+		if (p != string::npos) {
+			vfo_ = num100(replystr.substr(p+8));
+		}
+	}
+	get_trace(2, "get_vfo_adj()", str2hex(replystr.c_str(), replystr.length()));
+	return vfo_;
+}
+
+int RIG_IC7100::get_FILT(int mode)
+{
+	if (useB) return mode_filterB[mode];
+	return mode_filterA[mode];
+}
+
+void RIG_IC7100::set_FILT(int filter)
+{
+	if (filter < 1 || filter > 3)
+		return;
+
+	if (useB) {
+		B.filter = filter;
+		mode_filterB[B.imode] = filter;
+
+		cmd = pre_to;
+		cmd += '\x06';
+		cmd += mdval[B.imode];
+		if (B.imode < LSBD7100)
+			cmd += filter;
+		cmd.append( post );
+		waitFB("set mode/filter B");
+		set_trace(2, "set mode/filter B", str2hex(replystr.c_str(), replystr.length()));
+
+		if (B.imode >= LSBD7100) {
+			cmd = pre_to;
+			cmd += '\x1A'; cmd += '\x06';
+			cmd += '\x01';
+			cmd += filter;
+			cmd.append( post);
+			waitFB("set data mode B");
+			set_trace(2, "set data mode B", str2hex(replystr.c_str(), replystr.length()));
+		}
+	} else {
+		A.filter = filter;
+		mode_filterA[A.imode] = filter;
+
+		cmd = pre_to;
+		cmd += '\x06';
+		cmd += mdval[A.imode];
+		if (A.imode < LSBD7100)
+			cmd += filter;
+		cmd.append( post );
+		waitFB("set filter A ");
+		set_trace(2, "set filter A", str2hex(replystr.c_str(), replystr.length()));
+
+		if (A.imode >= LSBD7100) {
+			cmd = pre_to;
+			cmd += '\x1A'; cmd += '\x06';
+			cmd += '\x01';
+			cmd += filter;
+			cmd.append( post);
+			waitFB("set data mode A");
+			set_trace(2, "set data mode A", str2hex(replystr.c_str(), replystr.length()));
+		}
+	}
+}
+
+const char *RIG_IC7100::FILT(int val)
+{
+	if (val < 1) val = 1;
+	if (val > 3) val = 3;
+	return(szfilter[val - 1]);
+}
+
+const char *RIG_IC7100::nextFILT()
+{
+	int val = A.filter;
+	if (useB) val = B.filter;
+	val++;
+	if (val > 3) val = 1;
+	set_FILT(val);
+	return szfilter[val - 1];
+}
+
+void RIG_IC7100::set_FILTERS(std::string s)
+{
+	stringstream strm;
+	strm << s;
+	for (int i = 0; i < NUM_MODES; i++)
+		strm >> mode_filterA[i];
+	for (int i = 0; i < NUM_MODES; i++)
+		strm >> mode_filterB[i];
+	for (int i = 0; i < NUM_MODES; i++) {
+		if (mode_filterA[i] < 1) mode_filterA[i] = 1;
+		if (mode_filterA[i] > 3) mode_filterA[i] = 3;
+		if (mode_filterB[i] < 1) mode_filterB[i] = 1;
+		if (mode_filterB[i] > 3) mode_filterB[i] = 3;
+	}
+}
+
+std::string RIG_IC7100::get_FILTERS()
+{
+	for (int i = 0; i < NUM_MODES; i++) {
+		if (mode_filterA[i] < 1) mode_filterA[i] = 1;
+		if (mode_filterA[i] > 3) mode_filterA[i] = 3;
+		if (mode_filterB[i] < 1) mode_filterB[i] = 1;
+		if (mode_filterB[i] > 3) mode_filterB[i] = 3;
+	}
+	stringstream s;
+	for (int i = 0; i < NUM_MODES; i++)
+		s << mode_filterA[i] << " ";
+	for (int i = 0; i < NUM_MODES; i++)
+		s << mode_filterB[i] << " ";
+	return s.str();
+}
