@@ -34,6 +34,12 @@ const char IC7200name_[] = "IC-7200";
 #define NUM_FILTERS 3
 #define NUM_MODES  9
 
+enum {
+	LSB7200, USB7200, AM7200,
+	CW7200, RTTY7200,
+	CWR7200, RTTYR7200,
+	LSBD7200, USBD7200 };
+
 static int mode_filterA[NUM_MODES] = {1,1,1,1,1,1,1,1,1};
 static int mode_filterB[NUM_MODES] = {1,1,1,1,1,1,1,1,1};
 
@@ -48,7 +54,7 @@ const char *IC7200modes_[] = {
 
 const char mdval[] = { 0, 1, 2, 3, 4, 7, 8, 0, 1};
 
-const char IC7200_mode_type[] = { 
+static char IC7200_mode_type[] = { 
 'L', 'U', 'U', 'L', 'L', 'U', 'U',
 'L', 'U' };
 
@@ -214,6 +220,7 @@ RIG_IC7200::RIG_IC7200() {
 	precision = 1;
 	ndigits = 8;
 
+	CW_sense = 0; // normal
 };
 
 static inline void minmax(int min, int max, int &val)
@@ -853,6 +860,7 @@ void RIG_IC7200::set_mic_gain(int val)
 int RIG_IC7200::get_modeA()
 {
 	int md = A.imode;
+	size_t p = 0;
 
 	string resp = pre_fm;
 	resp += '\x04';
@@ -861,7 +869,7 @@ int RIG_IC7200::get_modeA()
 	cmd.append(post);
 
 	if (waitFOR(8, "get mode A")) {
-		size_t p = replystr.rfind(resp);
+		p = replystr.rfind(resp);
 		if (p != string::npos) {
 			md = replystr[p + 5];
 			if (md > 6) md -= 2;
@@ -876,7 +884,7 @@ int RIG_IC7200::get_modeA()
 	resp = pre_fm;
 	resp += "\x1A\x04";
 	if (waitFOR(9, "data mode?")) {
-		size_t p = replystr.rfind(resp);
+		p = replystr.rfind(resp);
 		if (p != string::npos) {
 			if ((replystr[p+6] & 0x01) == 0x01) {
 				if (md == 0) md = 7;
@@ -890,6 +898,17 @@ int RIG_IC7200::get_modeA()
 	get_trace(2, "get_data_modeA()", str2hex(replystr.c_str(), replystr.length()));
 	get_trace(4, "mode_filterA[", IC7200modes_[md], "] = ", szfilter[A.filter-1]);
 
+	if (A.imode == CW7200 || A.imode == CWR7200) {
+		cmd.assign(pre_to).append("\x1A\x03\x37");
+		resp.assign(pre_fm).append("\x1A\x03\x37");
+		if (waitFOR(9, "get CW sideband")) {
+			p = replystr.rfind(resp);
+			CW_sense = replystr[p + 7];
+			if (CW_sense) IC7200_mode_type[A.imode] = 'U';
+			else IC7200_mode_type[A.imode] = 'L';
+		}
+	}
+
 	return (A.imode = md);
 }
 
@@ -922,13 +941,15 @@ void RIG_IC7200::set_modeA(int val)
 int RIG_IC7200::get_modeB()
 {
 	int md = B.imode;
+	size_t p = 0;
+
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
 	string resp = pre_fm;
 	resp += '\x04';
 	if (waitFOR(8, "get mode B")) {
-		size_t p = replystr.rfind(resp);
+		p = replystr.rfind(resp);
 		if (p != string::npos) {
 			md = replystr[p+5];
 			if (md > 6) md -= 2;
@@ -943,7 +964,7 @@ int RIG_IC7200::get_modeB()
 	resp = pre_fm;
 	resp += "\x1A\x04";
 	if (waitFOR(9, "get data B")) {
-		size_t p = replystr.rfind(resp);
+		p = replystr.rfind(resp);
 		if (p != string::npos) {
 			if ((replystr[p+6] & 0x01) == 0x01) {
 				if (md == 0) md = 7;
@@ -957,6 +978,17 @@ int RIG_IC7200::get_modeB()
 	get_trace(2, "get_data_modeB()", str2hex(replystr.c_str(), replystr.length()));
 	get_trace(4, "mode_filterB[", IC7200modes_[md], "] = ", szfilter[B.filter-1]);
 
+	if (B.imode == CW7200 || B.imode == CWR7200) {
+		cmd.assign(pre_to).append("\x1A\x03\x37");
+		resp.assign(pre_fm).append("\x1A\x03\x37");
+		if (waitFOR(9, "get CW sideband")) {
+			p = replystr.rfind(resp);
+			CW_sense = replystr[p + 7];
+			if (CW_sense) IC7200_mode_type[B.imode] = 'U';
+			else IC7200_mode_type[B.imode] = 'L';
+		}
+	}
+
 	return (B.imode = md);
 }
 
@@ -1362,30 +1394,52 @@ void RIG_IC7200::set_vox_onoff()
 
 static bool IC7200_notchon = false;
 
-void RIG_IC7200::set_notch(bool on, int val)
+void RIG_IC7200::set_notch(bool on, int freq)
 {
-	int notch = val / 20 + 53;
-	if (notch > 255) notch = 255;
-	if (on != IC7200_notchon) {
-		cmd = pre_to;
-		cmd.append("\x16\x48");
-		cmd += on ? '\x01' : '\x00';
-		cmd.append(post);
-		waitFB("set notch");
-		IC7200_notchon = on;
-		set_trace(2, "set_notch_on_off()", str2hex(cmd.c_str(), cmd.length()));
+	int hexval;
+	switch (vfo->imode) {
+		default: case USB7200: case USBD7200: case RTTYR7200:
+			hexval = freq - 1500;
+			break;
+		case LSB7200: case LSBD7200: case RTTY7200:
+			hexval = 1500 - freq;
+			break;
+		case CW7200:
+			if (CW_sense)
+				hexval = freq - progStatus.cw_spot_tone;
+			else
+				hexval = progStatus.cw_spot_tone - freq;
+			break;
+		case CWR7200:
+			if (CW_sense)
+				hexval = progStatus.cw_spot_tone - freq;
+			else
+				hexval = freq - progStatus.cw_spot_tone;
+			break;
 	}
+
+	hexval /= 20;
+	hexval += 128;
+	if (hexval < 0) hexval = 0;
+	if (hexval > 255) hexval = 255;
+
+	cmd = pre_to;
+	cmd.append("\x16\x48");
+	cmd += on ? '\x01' : '\x00';
+	cmd.append(post);
+	waitFB("set notch");
+
 	cmd = pre_to;
 	cmd.append("\x14\x0D");
-	cmd.append(to_bcd(notch,3));
+	cmd.append(to_bcd(hexval,3));
 	cmd.append(post);
 	waitFB("set notch val");
-	set_trace(2, "set_notch_val()", str2hex(cmd.c_str(), cmd.length()));
 }
 
 bool RIG_IC7200::get_notch(int &val)
 {
 	bool on = false;
+	val = 1500;
 
 	string cstr = "\x16\x48";
 	string resp = pre_fm;
@@ -1394,24 +1448,41 @@ bool RIG_IC7200::get_notch(int &val)
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get notch")) {
-		get_trace(2, "get_notch_on_off()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			on = replystr[p + 6] ? 1 : 0;
+			on = replystr[p + 6];
 		cmd = pre_to;
 		resp = pre_fm;
 		cstr = "\x14\x0D";
 		cmd.append(cstr);
 		resp.append(cstr);
 		cmd.append(post);
-		if (waitFOR(9, "get notch val")) {
-			get_trace(2, "get_notch_val()", str2hex(replystr.c_str(), replystr.length()));
+		if (waitFOR(9, "notch val")) {
 			size_t p = replystr.rfind(resp);
 			if (p != string::npos) {
-				val = fm_bcd(replystr.substr(p+6),3);
-				val = (val - 53) * 20;
-				if (val < 0) val = 0;
-				if (val > 4040) val = 4040;
+				val = (int)ceil(fm_bcd(replystr.substr(p+6),3));
+				val -= 128;
+				val *= 20;
+				switch (vfo->imode) {
+					default: case USB7200: case USBD7200: case RTTYR7200:
+						val = 1500 + val;
+						break;
+					case LSB: case LSBD7200: case RTTY7200:
+						val = 1500 - val;
+						break;
+					case CW7200:
+						if (CW_sense)
+							val = progStatus.cw_spot_tone + val;
+						else
+							val = progStatus.cw_spot_tone - val;
+						break;
+					case CWR7200:
+						if (CW_sense)
+							val = progStatus.cw_spot_tone - val;
+						else
+							val = progStatus.cw_spot_tone + val;
+						break;
+				}
 			}
 		}
 	}
@@ -1420,9 +1491,17 @@ bool RIG_IC7200::get_notch(int &val)
 
 void RIG_IC7200::get_notch_min_max_step(int &min, int &max, int &step)
 {
-	min = 0;
-	max = 4040;
-	step = 20;
+	switch (vfo->imode) {
+		default:
+		case USB7200: case USBD7200: case RTTYR7200:
+		case LSB7200: case LSBD7200: case RTTY7200:
+			min = 0; max = 3000; step = 20; break;
+		case CW7200: case CWR7200:
+			min = progStatus.cw_spot_tone - 500;
+			max = progStatus.cw_spot_tone + 500;
+			step = 20;
+			break;
+	}
 }
 
 static int agcval = 0;
