@@ -51,15 +51,15 @@ static int mode_bwB[NUM_MODES] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
 static const char *szfilter[NUM_FILTERS] = {"1", "2", "3"};
 
 enum { 
-m73LSB, m73USB, m73AM, m73FM, m73CW, m73CWR, m73RTTY, m73RTTYR, 
-m73LSBD, m73USBD, m73AMD, m73FMD
+LSB7300, USB7300, AM7300, FM7300, CW7300, CWR7300, RTTY7300, RTTYR7300, 
+LSBD7300, USBD7300, AMD7300, FMD7300
 };
 
 const char *IC7300modes_[] = {
 	"LSB", "USB", "AM", "FM", "CW", "CW-R", "RTTY", "RTTY-R",
 	"LSB-D", "USB-D", "AM-D", "FM-D", NULL};
 
-const char IC7300_mode_type[] = {
+char IC7300_mode_type[] = {
 	'L', 'U', 'U', 'U', 'L', 'U', 'L', 'U',
 	'L', 'U', 'U', 'U' };
 
@@ -242,6 +242,8 @@ RIG_IC7300::RIG_IC7300() {
 
 	has_band_selection = true;
 
+	has_xcvr_auto_on_off = true;
+
 	precision = 1;
 	ndigits = 8;
 
@@ -250,6 +252,7 @@ RIG_IC7300::RIG_IC7300() {
 	can_change_alt_vfo = true;
 	has_a2b = true;
 
+	CW_sense = 0; // CW is LSB
 };
 
 static inline void minmax(int min, int max, int &val)
@@ -292,6 +295,33 @@ void RIG_IC7300::swapAB()
 	get_modeB();
 }
 
+void RIG_IC7300::set_xcvr_auto_on()
+{
+	cmd.clear();
+	int fes[] = { 2, 2, 2, 3, 7, 13, 25, 50, 75, 150, 150, 150 };
+	if (progStatus.comm_baudrate >= 0 && progStatus.comm_baudrate <= 11) {
+		cmd.append( fes[progStatus.comm_baudrate], '\xFE');
+	}
+	cmd.append(pre_to);
+	cmd += '\x18'; cmd += '\x01';
+	cmd.append(post);
+	waitFB("Power ON", 200);
+
+	cmd = pre_to;
+	cmd += '\x19'; cmd += '\x00';
+	cmd.append(post);
+	waitFOR(8, "get ID", 10000);
+}
+
+void RIG_IC7300::set_xcvr_auto_off()
+{
+	cmd.clear();
+	cmd.append(pre_to);
+	cmd += '\x18'; cmd += '\x00';
+	cmd.append(post);
+	waitFB("Power OFF", 200);
+}
+
 bool RIG_IC7300::check ()
 {
 	string resp = pre_fm;
@@ -426,7 +456,7 @@ int RIG_IC7300::get_modeA()
 		if (p == string::npos)
 			goto end_wait_modeA;
 
-		for (md = 0; md < m73LSBD; md++) {
+		for (md = 0; md < LSBD7300; md++) {
 			if (replystr[p+6] == IC7300_mode_nbr[md]) {
 				A.imode = md;
 				if (replystr[p+7] == 0x01 && A.imode < 4)
@@ -441,9 +471,22 @@ int RIG_IC7300::get_modeA()
 			mode_filterA[A.imode] = A.filter;
 	}
 
+end_wait_modeA:
+
 	get_trace(4, "get mode A[", IC7300modes_[A.imode], "] ", str2hex(replystr.c_str(), replystr.length()));
 
-end_wait_modeA:
+	if (A.imode == CW7300 || A.imode == CWR7300) {
+		cmd.assign(pre_to).append("\x1A\x05");
+		cmd += '\x00'; cmd += '\x53';
+		resp.assign(pre_fm).append("\x1A\x05");
+		resp += '\x00'; resp += '\x53';
+		if (waitFOR(10, "get CW sideband")) {
+			p = replystr.rfind(resp);
+			CW_sense = replystr[p+8];
+			if (CW_sense) IC7300_mode_type[A.imode] = 'U';
+			else IC7300_mode_type[A.imode] = 'L';
+		}
+	}
 
 	return A.imode;
 }
@@ -461,7 +504,7 @@ void RIG_IC7300::set_modeA(int val)
 	else
 		cmd += '\x00';					// selected vfo
 	cmd += IC7300_mode_nbr[A.imode];	// operating mode
-	if (A.imode >= m73LSBD)
+	if (A.imode >= LSBD7300)
 		cmd += '\x01';					// data mode
 	else
 		cmd += '\x00';
@@ -492,7 +535,7 @@ int RIG_IC7300::get_modeB()
 		if (p == string::npos)
 			goto end_wait_modeB;
 
-		for (md = 0; md < m73LSBD; md++) {
+		for (md = 0; md < LSBD7300; md++) {
 			if (replystr[p+6] == IC7300_mode_nbr[md]) {
 				B.imode = md;
 				if (replystr[p+7] == 0x01 && B.imode < 4)
@@ -505,12 +548,26 @@ int RIG_IC7300::get_modeB()
 		B.filter = replystr[p+8];
 	}
 
+end_wait_modeB:
+
 	get_trace(4, "get mode B[", IC7300modes_[B.imode], "] ", str2hex(replystr.c_str(), replystr.length()));
 
 	if (B.filter > 0 && B.filter < 4)
 		mode_filterB[B.imode] = B.filter;
 
-end_wait_modeB:
+	get_trace(4, "get mode A[", IC7300modes_[B.imode], "] ", str2hex(replystr.c_str(), replystr.length()));
+	if (B.imode == CW7300 || B.imode == CWR7300) {
+		cmd.assign(pre_to).append("\x1A\x05");
+		cmd += '\x00'; cmd += '\x53';
+		resp.assign(pre_fm).append("\x1A\x05");
+		resp += '\x00'; resp += '\x53';
+		if (waitFOR(10, "get CW sideband")) {
+			p = replystr.rfind(resp);
+			CW_sense = replystr[p+8];
+			if (CW_sense) IC7300_mode_type[B.imode] = 'U';
+			else IC7300_mode_type[B.imode] = 'L';
+		}
+	}
 
 	return B.imode;
 }
@@ -525,7 +582,7 @@ void RIG_IC7300::set_modeB(int val)
 	else
 		cmd += '\x01';					// unselected vfo
 	cmd += IC7300_mode_nbr[B.imode];	// operating mode
-	if (B.imode >= m73LSBD)
+	if (B.imode >= LSBD7300)
 		cmd += '\x01';					// data mode
 	else
 		cmd += '\x00';
@@ -554,7 +611,7 @@ void RIG_IC7300::set_FILT(int filter)
 		cmd += '\x26';
 		cmd += '\x00';						// selected vfo
 		cmd += IC7300_mode_nbr[B.imode];	// operating mode
-		if (B.imode >= m73LSBD) cmd += '\x01';	// data mode
+		if (B.imode >= LSBD7300) cmd += '\x01';	// data mode
 		else cmd += '\x00';
 		cmd += filter;						// filter
 		cmd.append( post );
@@ -568,7 +625,7 @@ void RIG_IC7300::set_FILT(int filter)
 		cmd += '\x26';
 		cmd += '\x00';						// selected vfo
 		cmd += IC7300_mode_nbr[A.imode];	// operating mode
-		if (A.imode >= m73LSBD) cmd += '\x01';	// data mode
+		if (A.imode >= LSBD7300) cmd += '\x01';	// data mode
 		else cmd += '\x00';
 		cmd += filter;						// filter
 		cmd.append( post );
@@ -1633,28 +1690,54 @@ int RIG_IC7300::get_auto_notch()
 
 static bool IC7300_notchon = false;
 
-void RIG_IC7300::set_notch(bool on, int val)
+void RIG_IC7300::set_notch(bool on, int freq)
 {
-	int notch = val / 20 + 53;
-	minmax(0, 255, notch);
-	if (on != IC7300_notchon) {
-		cmd = pre_to;
-		cmd.append("\x16\x48");
-		cmd += on ? '\x01' : '\x00';
-		cmd.append(post);
-		waitFB("set notch");
-		IC7300_notchon = on;
+	int hexval;
+	switch (vfo->imode) {
+		default: case USB7300: case USBD7300: case RTTYR7300:
+			hexval = freq - 1500;
+			break;
+		case LSB7300: case LSBD7300: case RTTY7300:
+			hexval = 1500 - freq;
+			break;
+		case CW7300:
+			if (CW_sense)
+				hexval = freq - progStatus.cw_spot_tone;
+			else
+				hexval = progStatus.cw_spot_tone - freq;
+			break;
+		case CWR7300:
+			if (CW_sense)
+				hexval = progStatus.cw_spot_tone - freq;
+			else
+				hexval = freq - progStatus.cw_spot_tone;
+			break;
 	}
+
+	hexval /= 20;
+	hexval += 128;
+	if (hexval < 0) hexval = 0;
+	if (hexval > 255) hexval = 255;
+
+	cmd = pre_to;
+	cmd.append("\x16\x48");
+	cmd += on ? '\x01' : '\x00';
+	cmd.append(post);
+	waitFB("set notch");
+	set_trace(2, "set_notch() ", str2hex(cmd.c_str(), cmd.length()));
+
 	cmd = pre_to;
 	cmd.append("\x14\x0D");
-	cmd.append(to_bcd(notch,3));
+	cmd.append(to_bcd(hexval,3));
 	cmd.append(post);
 	waitFB("set notch val");
+	set_trace(2, "set_notch_val() ", str2hex(cmd.c_str(), cmd.length()));
 }
 
 bool RIG_IC7300::get_notch(int &val)
 {
 	bool on = false;
+	val = 1500;
 
 	string cstr = "\x16\x48";
 	string resp = pre_fm;
@@ -1663,35 +1746,63 @@ bool RIG_IC7300::get_notch(int &val)
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get notch")) {
+		get_trace(2, "get_notch()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			on = replystr[p + 6] ? 1 : 0;
+			on = replystr[p + 6];
 		cmd = pre_to;
 		resp = pre_fm;
 		cstr = "\x14\x0D";
 		cmd.append(cstr);
 		resp.append(cstr);
 		cmd.append(post);
-		if (waitFOR(9, "get notch val")) {
+		if (waitFOR(9, "notch val")) {
 			size_t p = replystr.rfind(resp);
 			if (p != string::npos) {
-				val = fm_bcd(replystr.substr(p+6),3);
-				val = (val - 53) * 20;
-				if (val < 0) val = 0;
-				if (val > 4040) val = 4040;
+				val = (int)ceil(fm_bcd(replystr.substr(p+6),3));
+				val -= 128;
+				val *= 20;
+				switch (vfo->imode) {
+					default: case USB7300: case USBD7300: case RTTYR7300:
+						val = 1500 + val;
+						break;
+					case LSB: case LSBD7300: case RTTY7300:
+						val = 1500 - val;
+						break;
+					case CW7300:
+						if (CW_sense)
+							val = progStatus.cw_spot_tone + val;
+						else
+							val = progStatus.cw_spot_tone - val;
+						break;
+					case CWR7300:
+						if (CW_sense)
+							val = progStatus.cw_spot_tone - val;
+						else
+							val = progStatus.cw_spot_tone + val;
+						break;
+				}
 			}
+			get_trace(2, "get_notch_val() ", str2hex(replystr.c_str(), replystr.length()));
 		}
 	}
-	return (IC7300_notchon = on);
+	return on;
 }
 
 void RIG_IC7300::get_notch_min_max_step(int &min, int &max, int &step)
 {
-	min = 0;
-	max = 4040;
-	step = 20;
+	switch (vfo->imode) {
+		default:
+		case USB7300: case USBD7300: case RTTYR7300:
+		case LSB7300: case LSBD7300: case RTTY7300:
+			min = 0; max = 3000; step = 20; break;
+		case CW7300: case CWR7300:
+			min = progStatus.cw_spot_tone - 500;
+			max = progStatus.cw_spot_tone + 500;
+			step = 20;
+			break;
+	}
 }
-
 static int agcval = 3;
 int  RIG_IC7300::get_agc()
 {
