@@ -123,8 +123,6 @@ int  RIG_KX3::def_bandwidth(int m)
 	return def_mode_width[m];
 }
 
-extern int report_level;
-
 void RIG_KX3::initialize()
 {
 	debug::level = debug::INFO_LEVEL;
@@ -138,7 +136,6 @@ void RIG_KX3::initialize()
 	k3_widgets[5].W = sldrMICGAIN;
 	k3_widgets[6].W = sldrPOWER;
 
-	report_level = INFO;
 	cmd = "AI0;"; // disable auto-info
 	sendCommand(cmd);
 	showresp(INFO, ASC, "disable auto-info", cmd, replystr);
@@ -286,7 +283,7 @@ void RIG_KX3::set_pbt_values(int val)
 		case 5 :
 		case 7 :
 			if_shift_min = 100; if_shift_max = 2100;
-			if_shift_step = 10; if_shift_mid = 1000;
+			if_shift_step = 10; if_shift_mid = 1500;
 			break;
 	}
 	progStatus.shift_val = if_shift_mid;
