@@ -398,8 +398,6 @@ int rigbase::waitN(size_t n, int timeout, const char *sz, int pr)
 	return 0;
 }
 
-int report_level = INFO;
-
 int rigbase::wait_char(int ch, size_t n, int timeout, const char *sz, int pr)
 {
 	guard_lock reply_lock(&mutex_replystr);
@@ -419,7 +417,7 @@ int rigbase::wait_char(int ch, size_t n, int timeout, const char *sz, int pr)
 
 	if(!progStatus.use_tcpip && !RigSerial->IsOpen()) {
 		snprintf(sztemp, sizeof(sztemp), "TEST %s", sz);
-		showresp(report_level, pr, sztemp, tosend, replystr);
+		showresp(DEBUG, pr, sztemp, tosend, replystr);
 		return 0;
 	}
 
@@ -434,7 +432,7 @@ int rigbase::wait_char(int ch, size_t n, int timeout, const char *sz, int pr)
 			replystr = returned;
 			waited = cnt * 10 + delay;
 			snprintf(sztemp, sizeof(sztemp), "%s OK %d ms", sz, waited);
-			showresp(report_level, pr, sztemp, cmd, returned);
+			showresp(DEBUG, pr, sztemp, cmd, returned);
 			return replystr.length();
 		}
 		MilliSleep(10);
