@@ -1792,16 +1792,14 @@ public:
 			}
 		} else
 			cmd = command;
-
 // lock out polling loops until done
 		{
 			guard_lock lock1(&mutex_srvc_reqs);
 			guard_lock lock2(&mutex_serial);
-			sendCommand(cmd, cmd.length());
+			sendCommand(cmd, 0, 0);//cmd.length());
 
 			retstr.clear();
 			waitResponse(100);
-
 			if (!respstr.empty()) {
 				retstr = usehex ? 
 					str2hex(respstr.c_str(), respstr.length()) :
@@ -1820,6 +1818,27 @@ public:
 } rig_cat_string(&rig_server);
 
 
+static void shutdown(void *)
+{
+	cbExit();
+}
+
+class rig_shutdown : public XmlRpcServerMethod {
+public:
+	rig_shutdown(XmlRpcServer* s) : XmlRpcServerMethod("rig.shutdown", s) {}
+
+	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized) {
+			result = 0;
+			return;
+		}
+		Fl::awake(shutdown, static_cast<void *>(0));
+	}
+	std::string help() { return std::string("turn off rig / close flrig"); }
+
+} rig_shutdown(&rig_server);
+
+
 struct MLIST {
 	string name; string signature; string help;
 } mlist[] = {
@@ -1869,7 +1888,8 @@ struct MLIST {
 	{ "rig.set_rfgain",   "i:i", "sets rf gain control" },
 	{ "rig.set_micgain",  "i:i", "sets mic gain control" },
 	{ "rig.swap",         "i:i", "execute vfo swap" },
-	{ "rig.cat_string",   "s:s", "execute CAT string" }
+	{ "rig.cat_string",   "s:s", "execute CAT string" },
+	{ "rig.shutdown",     "i:i", "shutdown xcvr & flrig" }
 };
 
 class rig_list_methods : public XmlRpcServerMethod {
